@@ -7,15 +7,16 @@
 #include <KItinerary/CountryDb>
 
 #include <config-kitinerary.h>
-#include <knowledgedb/alphaid.h>
+#include "knowledgedb/alphaid.h"
 #include <knowledgedb/timezonedb.cpp>
-#include <knowledgedb/trainstationdb.h>
+#include "knowledgedb/trainstationdb.h"
 
 #include <QDebug>
 #include <QObject>
 #include <QTest>
 #include <QTimeZone>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace KItinerary;
 using namespace KItinerary::KnowledgeDb;
 
@@ -79,8 +80,8 @@ private Q_SLOTS:
        QVERIFY(!(id1 == id2));
        QVERIFY(!(id1 != id1));
 
-       QCOMPARE(id1.toString(), QLatin1String("ABC"));
-       QCOMPARE(id2.toString(), QLatin1String("CBA"));
+       QCOMPARE(id1.toString(), QLatin1StringView("ABC"));
+       QCOMPARE(id2.toString(), QLatin1StringView("CBA"));
 
        constexpr ID3 id3;
        QVERIFY(!id3.isValid());
@@ -93,16 +94,16 @@ private Q_SLOTS:
     {
         auto sncf = KnowledgeDb::SncfStationId(QStringLiteral("FRPNO"));
         QVERIFY(sncf.isValid());
-        QCOMPARE(sncf.toString(), QLatin1String("FRPNO"));
+        QCOMPARE(sncf.toString(), QLatin1StringView("FRPNO"));
         sncf = KnowledgeDb::SncfStationId(QStringLiteral("Abc"));
         QVERIFY(!sncf.isValid());
         sncf =  KnowledgeDb::SncfStationId(QStringLiteral("CHZID"));
         QVERIFY(sncf.isValid());
-        QCOMPARE(sncf.toString(), QLatin1String("CHZID"));
+        QCOMPARE(sncf.toString(), QLatin1StringView("CHZID"));
 
         auto vrCode = KnowledgeDb::VRStationCode(QStringLiteral("HSL"));
         QVERIFY(vrCode.isValid());
-        QCOMPARE(vrCode.toString(), QLatin1String("HSL"));
+        QCOMPARE(vrCode.toString(), QLatin1StringView("HSL"));
     }
 
     void testIBNRLookup()
@@ -337,11 +338,37 @@ private Q_SLOTS:
         QVERIFY(!station.coordinate.isValid());
     }
 
+    void testFinishStationCode()
+    {
+        constexpr const VRStationCode hki("HKI\0");
+        QVERIFY(hki.value() > 0);
+        auto code = VRStationCode(u"HKI"_s);
+        QVERIFY(hki == code);
+        QCOMPARE(hki.toString(), "HKI"_L1);
+        QCOMPARE(code.toString(), "HKI"_L1);
+
+        constexpr const VRStationCode ol("OL\0\0");
+        QVERIFY(ol.isValid());
+        QVERIFY(ol != hki);
+        QCOMPARE(ol.toString(), "OL"_L1);
+
+        constexpr const VRStationCode kja("KJ[\0");
+        QVERIFY(kja.isValid());
+        code = VRStationCode(u"KJÄ"_s);
+        QVERIFY(code.isValid());
+        QVERIFY(kja == code);
+        QCOMPARE(kja.toString(), u"KJÄ");
+        QCOMPARE(code.toString(), u"KJÄ");
+    }
+
     void testFinishStationCodeLookup()
     {
         auto station = KnowledgeDb::stationForVRStationCode(VRStationCode(QStringLiteral("HKI")));
         QVERIFY(station.coordinate.isValid());
 
+        station = KnowledgeDb::stationForVRStationCode(VRStationCode(u"KJÄ"_s));
+        QVERIFY(station.coordinate.isValid());
+
         station = KnowledgeDb::stationForVRStationCode(VRStationCode(QStringLiteral("BLÄ")));
         QVERIFY(!station.coordinate.isValid());
     }
