@@ -115,7 +115,7 @@ void ExtractorDocumentNodeFactoryStatic::registerBuiltIn()
     registerProcessor<PdfDocumentProcessor>(u"application/pdf");
     registerProcessor<PkPassDocumentProcessor>(u"application/vnd.apple.pkpass");
     registerProcessor<IcalEventProcessor>(u"internal/event");
-    registerProcessor<ImageDocumentProcessor>(u"internal/qimage", {u"image/png", u"image/jpeg"});
+    registerProcessor<ImageDocumentProcessor>(u"internal/qimage", {u"image/png", u"image/jpeg", u"image/gif"});
     registerProcessor<ElbDocumentProcessor>(u"internal/era-elb");
     registerProcessor<SsbDocumentProcessor>(u"internal/era-ssb");
     registerProcessor<IataBcbpDocumentProcessor>(u"internal/iata-bcbp");
